@@ -14,14 +14,14 @@ class Server:
         self.packagePrintBlacklist.append("ALIVE")
         self.packagePrintBlacklist.append("ALIVE_OK")
 
-    def start(self, host="", port=0, maxClients=10):
+    def start(self, host="", port=0, maxClients=10, printUnsignedData=True):
         if host == "":
             host = socket.gethostbyname(socket.gethostname())
         logger.log("§8[§eSERVER§8] §6Starting...")
         try:
             self.serverSocket.bind((host, port))
             self.serverSocket.listen(maxClients)
-            logger.log("§8[§eSERVER§8] §aListen on §6" + str((host, port)))
+            logger.log("§8[§eSERVER§8] §aListening on §6" + str((host, port)))
         except Exception as e:
             logger.log("§8[§eSERVER§8] §8[§cERROR§8] §cFailed: " + str(e))
             self.error = 1
@@ -37,10 +37,12 @@ class Server:
                             if recvData.endswith("}" + self.seq):
                                 if lastData != "":
                                     recvData = lastData + recvData
-                                    logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cUnsigned data repaired")
+                                    if printUnsignedData:
+                                        logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cUnsigned data repaired")
                         if not recvData.endswith("}" + self.seq):
                             lastData += recvData
-                            logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cReceiving unsigned data: §r" + recvData)
+                            if printUnsignedData:
+                                logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cReceiving unsigned data: §r" + recvData)
                             continue
                         if "}" + self.seq + "{" in recvData:
                             recvDataList = recvData.split("}" + self.seq + "{")
@@ -76,7 +78,7 @@ class Server:
                                 else:
                                     logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cReceiving not authenticated package: §r" + data["METHOD"])
                 except Exception as e:
-                    logger.log("§8[§eCLIENT§8] §8[§cWARNING§8] §cException: §4" + str(e))
+                    logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cException: §4" + str(e))
                     break
             self.clientSocks.remove(clientSocket)
             for client in self.clients:
